@@ -234,7 +234,7 @@ class Isolate(dict):
                               f"_{feat_res_dict['nuc_change']}")
                 aa_format = (f"{feat_res_dict['seq_regions'][0]}"
                              f"_{feat_res_dict['ref_start_pos']}"
-                             f"_{feat_res_dict['var_aa']}")
+                             f"_{var_aa}")  # var_aa can be None
                 return nuc_format, aa_format
             # Amino acid mutation
             else:
@@ -395,7 +395,7 @@ class Isolate(dict):
         hit = DBHit(name=gene_info["name"],
                     identity=gene_info["identity"],
                     match_length=gene_info["alignment_length"],
-                    ref_length=gene_info["ref_seq_lenght"],
+                    ref_length=gene_info["ref_seq_length"],
                     start_ref=gene_info["ref_start_pos"],
                     end_ref=gene_info["ref_end_pos"],
                     acc=gene_info["ref_acc"],
@@ -481,7 +481,7 @@ class Isolate(dict):
                             elif(feature.hit.match_category > best_match):
                                 best_match = feature.hit.match_category
 
-                                output_str += "\t" + str(best_match)
+                    output_str += "\t" + str(best_match)
 
                     gene_list = ab.get_gene_namewacc(tostring=True)
                     mut_list = ab.get_mut_namewannot(tostring=True)
